# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ImageInfo


def test_ImageInfo_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr="%s",
            extensions=None,
            position=1,
        ),
        subjects_dir=dict(),
    )
    inputs = ImageInfo.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ImageInfo_outputs():
    output_map = dict(
        TE=dict(),
        TI=dict(),
        TR=dict(),
        data_type=dict(),
        dimensions=dict(),
        file_format=dict(),
        info=dict(),
        orientation=dict(),
        out_file=dict(
            extensions=None,
        ),
        ph_enc_dir=dict(),
        vox_sizes=dict(),
    )
    outputs = ImageInfo.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ApplyInverseDeformation


def test_ApplyInverseDeformation_inputs():
    input_map = dict(
        bounding_box=dict(
            field="comp{1}.inv.comp{1}.sn2def.bb",
        ),
        deformation=dict(
            extensions=None,
            field="comp{1}.inv.comp{1}.sn2def.matname",
            xor=["deformation_field"],
        ),
        deformation_field=dict(
            extensions=None,
            field="comp{1}.inv.comp{1}.def",
            xor=["deformation"],
        ),
        in_files=dict(
            field="fnames",
            mandatory=True,
        ),
        interpolation=dict(
            field="interp",
        ),
        matlab_cmd=dict(),
        mfile=dict(
            usedefault=True,
        ),
        paths=dict(),
        target=dict(
            extensions=None,
            field="comp{1}.inv.space",
        ),
        use_mcr=dict(),
        use_v8struct=dict(
            min_ver="8",
            usedefault=True,
        ),
        voxel_sizes=dict(
            field="comp{1}.inv.comp{1}.sn2def.vox",
        ),
    )
    inputs = ApplyInverseDeformation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ApplyInverseDeformation_outputs():
    output_map = dict(
        out_files=dict(),
    )
    outputs = ApplyInverseDeformation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import MultiChannelNewSegment


def test_MultiChannelNewSegment_inputs():
    input_map = dict(
        affine_regularization=dict(
            field="warp.affreg",
        ),
        channels=dict(
            field="channel",
        ),
        matlab_cmd=dict(),
        mfile=dict(
            usedefault=True,
        ),
        paths=dict(),
        sampling_distance=dict(
            field="warp.samp",
        ),
        tissues=dict(
            field="tissue",
        ),
        use_mcr=dict(),
        use_v8struct=dict(
            min_ver="8",
            usedefault=True,
        ),
        warping_regularization=dict(
            field="warp.reg",
        ),
        write_deformation_fields=dict(
            field="warp.write",
        ),
    )
    inputs = MultiChannelNewSegment.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MultiChannelNewSegment_outputs():
    output_map = dict(
        bias_corrected_images=dict(),
        bias_field_images=dict(),
        dartel_input_images=dict(),
        forward_deformation_field=dict(),
        inverse_deformation_field=dict(),
        modulated_class_images=dict(),
        native_class_images=dict(),
        normalized_class_images=dict(),
        transformation_mat=dict(),
    )
    outputs = MultiChannelNewSegment.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dcmstack import CopyMeta


def test_CopyMeta_inputs():
    input_map = dict(
        dest_file=dict(
            extensions=None,
            mandatory=True,
        ),
        exclude_classes=dict(),
        include_classes=dict(),
        src_file=dict(
            extensions=None,
            mandatory=True,
        ),
    )
    inputs = CopyMeta.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CopyMeta_outputs():
    output_map = dict(
        dest_file=dict(
            extensions=None,
        ),
    )
    outputs = CopyMeta.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import DWIJointRicianLMMSEFilter


def test_DWIJointRicianLMMSEFilter_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        compressOutput=dict(
            argstr="--compressOutput ",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputVolume=dict(
            argstr="%s",
            extensions=None,
            position=-2,
        ),
        ng=dict(
            argstr="--ng %d",
        ),
        outputVolume=dict(
            argstr="%s",
            hash_files=False,
            position=-1,
        ),
        re=dict(
            argstr="--re %s",
            sep=",",
        ),
        rf=dict(
            argstr="--rf %s",
            sep=",",
        ),
    )
    inputs = DWIJointRicianLMMSEFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DWIJointRicianLMMSEFilter_outputs():
    output_map = dict(
        outputVolume=dict(
            extensions=None,
            position=-1,
        ),
    )
    outputs = DWIJointRicianLMMSEFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..base import AFNIPythonCommand


def test_AFNIPythonCommand_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_afni",
        ),
        outputtype=dict(),
    )
    inputs = AFNIPythonCommand.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..classify import BRAINSPosteriorToContinuousClass


def test_BRAINSPosteriorToContinuousClass_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputBasalGmVolume=dict(
            argstr="--inputBasalGmVolume %s",
            extensions=None,
        ),
        inputCrblGmVolume=dict(
            argstr="--inputCrblGmVolume %s",
            extensions=None,
        ),
        inputCrblWmVolume=dict(
            argstr="--inputCrblWmVolume %s",
            extensions=None,
        ),
        inputCsfVolume=dict(
            argstr="--inputCsfVolume %s",
            extensions=None,
        ),
        inputSurfaceGmVolume=dict(
            argstr="--inputSurfaceGmVolume %s",
            extensions=None,
        ),
        inputVbVolume=dict(
            argstr="--inputVbVolume %s",
            extensions=None,
        ),
        inputWhiteVolume=dict(
            argstr="--inputWhiteVolume %s",
            extensions=None,
        ),
        outputVolume=dict(
            argstr="--outputVolume %s",
            hash_files=False,
        ),
    )
    inputs = BRAINSPosteriorToContinuousClass.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSPosteriorToContinuousClass_outputs():
    output_map = dict(
        outputVolume=dict(
            extensions=None,
        ),
    )
    outputs = BRAINSPosteriorToContinuousClass.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..extractskeleton import ExtractSkeleton


def test_ExtractSkeleton_inputs():
    input_map = dict(
        InputImageFileName=dict(
            argstr="%s",
            extensions=None,
            position=-2,
        ),
        OutputImageFileName=dict(
            argstr="%s",
            hash_files=False,
            position=-1,
        ),
        args=dict(
            argstr="%s",
        ),
        dontPrune=dict(
            argstr="--dontPrune ",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        numPoints=dict(
            argstr="--numPoints %d",
        ),
        pointsFile=dict(
            argstr="--pointsFile %s",
        ),
        type=dict(
            argstr="--type %s",
        ),
    )
    inputs = ExtractSkeleton.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ExtractSkeleton_outputs():
    output_map = dict(
        OutputImageFileName=dict(
            extensions=None,
            position=-1,
        ),
    )
    outputs = ExtractSkeleton.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Copy


def test_Copy_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        input_file=dict(
            argstr="%s",
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_copy.mnc",
            position=-1,
        ),
        pixel_values=dict(
            argstr="-pixel_values",
            xor=("pixel_values", "real_values"),
        ),
        real_values=dict(
            argstr="-real_values",
            xor=("pixel_values", "real_values"),
        ),
    )
    inputs = Copy.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Copy_outputs():
    output_map = dict(
        output_file=dict(
            extensions=None,
        ),
    )
    outputs = Copy.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import ClipLevel


def test_ClipLevel_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        doall=dict(
            argstr="-doall",
            position=3,
            xor="grad",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        grad=dict(
            argstr="-grad %s",
            extensions=None,
            position=3,
            xor="doall",
        ),
        in_file=dict(
            argstr="%s",
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        mfrac=dict(
            argstr="-mfrac %s",
            position=2,
        ),
    )
    inputs = ClipLevel.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ClipLevel_outputs():
    output_map = dict(
        clip_val=dict(),
    )
    outputs = ClipLevel.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSROIAuto


def test_BRAINSROIAuto_inputs():
    input_map = dict(
        ROIAutoDilateSize=dict(
            argstr="--ROIAutoDilateSize %f",
        ),
        args=dict(
            argstr="%s",
        ),
        closingSize=dict(
            argstr="--closingSize %f",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputVolume=dict(
            argstr="--inputVolume %s",
            extensions=None,
        ),
        numberOfThreads=dict(
            argstr="--numberOfThreads %d",
        ),
        otsuPercentileThreshold=dict(
            argstr="--otsuPercentileThreshold %f",
        ),
        outputClippedVolumeROI=dict(
            argstr="--outputClippedVolumeROI %s",
            hash_files=False,
        ),
        outputROIMaskVolume=dict(
            argstr="--outputROIMaskVolume %s",
            hash_files=False,
        ),
        outputVolumePixelType=dict(
            argstr="--outputVolumePixelType %s",
        ),
        thresholdCorrectionFactor=dict(
            argstr="--thresholdCorrectionFactor %f",
        ),
    )
    inputs = BRAINSROIAuto.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSROIAuto_outputs():
    output_map = dict(
        outputClippedVolumeROI=dict(
            extensions=None,
        ),
        outputROIMaskVolume=dict(
            extensions=None,
        ),
    )
    outputs = BRAINSROIAuto.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import TalairachAVI


def test_TalairachAVI_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        atlas=dict(
            argstr="--atlas %s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr="--i %s",
            extensions=None,
            mandatory=True,
        ),
        out_file=dict(
            argstr="--xfm %s",
            extensions=None,
            mandatory=True,
        ),
        subjects_dir=dict(),
    )
    inputs = TalairachAVI.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TalairachAVI_outputs():
    output_map = dict(
        out_file=dict(
            extensions=None,
        ),
        out_log=dict(
            extensions=None,
        ),
        out_txt=dict(
            extensions=None,
        ),
    )
    outputs = TalairachAVI.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..connectivity import LabelConfig


def test_LabelConfig_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_config=dict(
            argstr="%s",
            extensions=None,
            position=-2,
        ),
        in_file=dict(
            argstr="%s",
            extensions=None,
            mandatory=True,
            position=-3,
        ),
        lut_aal=dict(
            argstr="-lut_aal %s",
            extensions=None,
        ),
        lut_basic=dict(
            argstr="-lut_basic %s",
            extensions=None,
        ),
        lut_fs=dict(
            argstr="-lut_freesurfer %s",
            extensions=None,
        ),
        lut_itksnap=dict(
            argstr="-lut_itksnap %s",
            extensions=None,
        ),
        nthreads=dict(
            argstr="-nthreads %d",
            nohash=True,
        ),
        out_file=dict(
            argstr="%s",
            extensions=None,
            mandatory=True,
            position=-1,
            usedefault=True,
        ),
        spine=dict(
            argstr="-spine %s",
            extensions=None,
        ),
    )
    inputs = LabelConfig.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_LabelConfig_outputs():
    output_map = dict(
        out_file=dict(
            extensions=None,
        ),
    )
    outputs = LabelConfig.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
